@@ -1,3 +1,15 @@
+#  Licensed under the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License. You may obtain
+#  a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#  License for the specific language governing permissions and limitations
+#  under the License.
+
 """Application base class.
 """
 
@@ -10,10 +22,10 @@ import os
 import six
 import sys
 
-from cliff import argparse
-from .complete import CompleteCommand
-from .help import HelpAction, HelpCommand
-from .utils import damerau_levenshtein, COST
+from cliff import _argparse
+from . import complete
+from . import help
+from . import utils
 
 
 logging.getLogger('cliff').addHandler(logging.NullHandler())
@@ -58,8 +70,8 @@ class App(object):
         """Initialize the application.
         """
         self.command_manager = command_manager
-        self.command_manager.add_command('help', HelpCommand)
-        self.command_manager.add_command('complete', CompleteCommand)
+        self.command_manager.add_command('help', help.HelpCommand)
+        self.command_manager.add_command('complete', complete.CompleteCommand)
         self._set_streams(stdin, stdout, stderr)
         self.interactive_app_factory = interactive_app_factory
         self.deferred_help = deferred_help
@@ -131,7 +143,7 @@ class App(object):
         :paramtype extra_kwargs: dict
         """
         argparse_kwargs = argparse_kwargs or {}
-        parser = argparse.ArgumentParser(
+        parser = _argparse.ArgumentParser(
             description=description,
             add_help=False,
             **argparse_kwargs
@@ -172,7 +184,7 @@ class App(object):
         else:
             parser.add_argument(
                 '-h', '--help',
-                action=HelpAction,
+                action=help.HelpAction,
                 nargs=0,
                 default=self,  # tricky
                 help="Show help message and exit.",
@@ -222,7 +234,7 @@ class App(object):
            explicitly this method in initialize_app.
         """
         if self.deferred_help and self.options.deferred_help:
-            action = HelpAction(None, None, default=self)
+            action = help.HelpAction(None, None, default=self)
             action(self.parser, self.options, None, None)
 
     def run(self, argv):
@@ -329,7 +341,8 @@ class App(object):
                 dist.append((0, candidate))
                 continue
             # Levenshtein distance
-            dist.append((damerau_levenshtein(cmd, prefix, COST)+1, candidate))
+            dist.append((utils.damerau_levenshtein(cmd, prefix, utils.COST)+1,
+                         candidate))
 
         matches = []
         match_distance = 0
@@ -358,7 +371,7 @@ class App(object):
                     article = 'an'
                 self.stdout.write('%s: \'%s\' is not %s %s command. '
                                   'See \'%s --help\'.\n'
-                                  % (self.NAME, the_cmd, article,
+                                  % (self.NAME, ' '.join(argv), article,
                                       self.NAME, self.NAME))
                 self.stdout.write('Did you mean one of these?\n')
                 for match in fuzzy_matches:
